@@ -9,12 +9,12 @@ See http://cine.io/ for documentation.
 
 """
 
-from .cine_io import Client
+from .cine_io import Client, Project, Stream, requests
 
-__all__ = [Client]
+__all__ = [Client, Project, Stream, requests]
 __author__ = 'cine.io engineering'
 __copyright__ = 'Copyright 2014 cine.io'
 __license__ = 'MIT'
 __title__ = 'cineio'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 __version_info__ = tuple(int(i) for i in __version__.split('.'))
